@@ -12,9 +12,8 @@ import requests
 from functools import lru_cache
 from appzoo import App
 
-from appzoo.utils import get_zk_config
+from appzoo.utils import cfg
 
-cfg = get_zk_config("mipush.ann.cfg")
 simbert_url = cfg['simbert_url']
 xindao_search_url = cfg['xindao_search_url']
 
